==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/widgets/CoverLabel.h <==
/****************************************************************************************
 * Copyright (c) 2004 Mark Kretschmann <kretschmann@kde.org>                            *
 * Copyright (c) 2004 Stefan Bogner <bochi@online.ms>                                   *
 * Copyright (c) 2007 Dan Meltzer <parallelgrapefruit@gmail.com>                        *
 * Copyright (c) 2009 Martin Sandsmark <sandsmark@samfundet.no>                         *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AMAROK_COVERLABEL_H
#define AMAROK_COVERLABEL_H

#include <QLabel>
#include <QMouseEvent>

class CoverLabel : public QLabel
{
public:
    explicit CoverLabel( QWidget * parent, Qt::WindowFlags f = 0 );

    void setInformation( const QString &artist, const QString &album );

protected:
    virtual void mouseReleaseEvent( QMouseEvent *pEvent );

private:
    QString m_artist;
    QString m_album;
};

#endif /* AMAROK_COVERLABEL_H */

==> amarok_3.2.2.orig.tar.xz: amarok-3.2.2/src/widgets/CoverLabel.h <==
/****************************************************************************************
 * Copyright (c) 2004 Mark Kretschmann <kretschmann@kde.org>                            *
 * Copyright (c) 2004 Stefan Bogner <bochi@online.ms>                                   *
 * Copyright (c) 2007 Dan Meltzer <parallelgrapefruit@gmail.com>                        *
 * Copyright (c) 2009 Martin Sandsmark <sandsmark@samfundet.no>                         *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef AMAROK_COVERLABEL_H
#define AMAROK_COVERLABEL_H

#include <QLabel>
#include <QMouseEvent>

class CoverLabel : public QLabel
{
public:
    explicit CoverLabel( QWidget * parent, Qt::WindowFlags f = {} );

    void setInformation( const QString &artist, const QString &album );

protected:
    void mouseReleaseEvent( QMouseEvent *pEvent ) override;

private:
    QString m_artist;
    QString m_album;
};

#endif /* AMAROK_COVERLABEL_H */
